import .Pipe ;

//! An instance of the Gnuplot class is a pipe to a running gnuplot. You can use write to send orders to It, or use some of the methods defined in this class to do It.
class Gnuplot {
  inherit Pipe;
  void create( void | string path ) 
  {
    string exe ;
    if ( path ) 
      {
        exe = path ;
      }
    else
      {
	exe = "gnuplot" ;
      }
    ::create( ({ exe }) );
  }
  
  //! This method is just like the analog method in class Pipe, but adds a '\n' for convenience.
  void write ( string what )
  {
    ::write( what + "\n");
  }

  //! Closes the running gnuplot.
  void quit ()
  {
    write("quit");
  }
  
  //!Plots f(x). Example: plot( "sin(x)" );
  void plot( string func )
  {
    write("plot " + func );
  }
  
  //! When doing 2D parametric plots, the parameter is t. Example: to draw a circle, just do parametricPlot( " cos(t), sin(t) " );
  void parametricPlot( string func )
  {
    set("parametric");
    plot(func );
    unset("parametric");
  }
  
  //!Plots f(x,y). Example: plot("sin(x) * cos(y)") ;
  void splot( string func )
  {
    write("splot " + func );
  }
  
  //! When doing 3D parametric plots, the parameters are u and v.
  void parametricSplot( string func )
  {
    set("parametric");
    splot( func );
    unset("parametric" );
  }
  
  //!Uses the pm3d option to draw surface maps.
  void surfaceSplot( string func )
  {
    set("pm3d");
    splot( func );
    unset("pm3d");
  }
  
  //! Sets some property of gnuplot.
  void set ( string what )
  {
    write("set " + what );
  }
  
  //! Unsets some property of gnuplot.
  void unset ( string what )
  {
    write("unset " + what );
  }
  
  //! Enables the grid.
  void setGrid()
  {
    set("grid");
  }
  
  //! Disables the grid.
  void unsetGrid()
  {
    unset("grid");
  }

  //!Enables the parametric mode.
  void setParametric()
  {
    set("parametric");
  }
  
  //!Disables the parametric mode.
  void unsetParametric()
  {
    unset("parametric");
  }
  
  //! Updates the screen
  void update()
  {
    write("replot");
  }
  
  //! Saves a postscript copy of the screen. This method has something similar to a bug: if your screen has a parametric plot on It, this doesn't work. In that case, please do setParametric() ; save2postscript() ; unsetParametric();
  void save2postscript (string  filename )
  {
    write( "set terminal postscript color" );
    write(  "set output '" +  filename + "'") ;
    update();
    write ( "set terminal pop") ;
  }
}



int main () 
{
  Gnuplot plot = Gnuplot();
  plot->setGrid();
  plot->plot("sin(x)");
  Stdio.stdin->gets();
  plot->unsetGrid();
  plot->splot("cos(x)*sin(y)");
  Stdio.stdin->gets();
  plot->parametricPlot("cos(t), sin(t)");
  Stdio.stdin->gets();
  plot->parametricSplot("cos(u) * sin(v), cos(u)* cos(v), sin(u) " ) ;
  Stdio.stdin->gets();
  plot->plot("x*sin(x)");
  plot->save2postscript("myScreen.ps");
  return 0;
}


